==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "Files" : "Filer",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du blev nævnt på \"{file}\", i en kommentar af en konto, som siden er blevet slettet",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nævnte dig i en kommentar til \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin til at tilføje kommentarer til filer",
    "Edit comment" : "Rediger kommentar",
    "Delete comment" : "Slet kommentar",
    "Cancel edit" : "Annuller redigering",
    "New comment" : "Ny kommentar",
    "Write a comment …" : "Skriv kommentar…",
    "Post comment" : "Skriv kommentar",
    "@ for mentions, : for emoji, / for smart picker" : "\"@\" for at omtale, \":\" for emojis, \"/\" for Smart Vælger",
    "Could not reload comments" : "Kunne ikke indlæse kommentarer",
    "Failed to mark comments as read" : "Kunne ikke markere kommentarer som læst",
    "Unable to load the comments list" : "Kan ikke indlæse kommentarlisten",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "No more messages" : "Ikke flere beskeder",
    "Retry" : "Prøv igen",
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nye kommentarer"],
    "Comment" : "Kommenter",
    "An error occurred while trying to edit the comment" : "Der opstod en fejl under forsøget på at redigere kommentaren",
    "Comment deleted" : "Kommentar slettet",
    "An error occurred while trying to delete the comment" : "Der opstod en fejl under forsøget på at slette kommentaren",
    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/comments/l10n/da.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentarer",
    "You commented" : "Du kommenterede",
    "{author} commented" : "{author} kommenterede",
    "You commented on %1$s" : "Du kommenterede %1$s",
    "You commented on {file}" : "Du kommenterede {file}",
    "%1$s commented on %2$s" : "%1$s kommenterede %2$s",
    "{author} commented on {file}" : "{author} kommenterede {file}",
    "<strong>Comments</strong> for files" : "<strong>Kommentarer</strong> for filer",
    "Files" : "Filer",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Du blev nævnt på \"{file}\", i en kommentar af en konto, som siden er blevet slettet",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} nævnte dig i en kommentar til \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin til at tilføje kommentarer til filer",
    "Edit comment" : "Redigér kommentar",
    "Delete comment" : "Slet kommentar",
    "Cancel edit" : "Annullér redigering",
    "New comment" : "Ny kommentar",
    "Write a comment …" : "Skriv kommentar…",
    "Post comment" : "Skriv kommentar",
    "@ for mentions, : for emoji, / for smart picker" : "\"@\" for at omtale, \":\" for emojis, \"/\" for Smart Vælger",
    "Could not reload comments" : "Kunne ikke indlæse kommentarer",
    "Failed to mark comments as read" : "Kunne ikke markere kommentarer som læst",
    "Unable to load the comments list" : "Kan ikke indlæse kommentarlisten",
    "No comments yet, start the conversation!" : "Ingen kommentarer endnu, start samtalen!",
    "No more messages" : "Ikke flere beskeder",
    "Retry" : "Prøv igen",
    "_1 new comment_::_{unread} new comments_" : ["1 ny kommentar","{unread} nye kommentarer"],
    "Comment" : "Kommenter",
    "An error occurred while trying to edit the comment" : "Der opstod en fejl under forsøget på at redigere kommentaren",
    "Comment deleted" : "Kommentar slettet",
    "An error occurred while trying to delete the comment" : "Der opstod en fejl under forsøget på at slette kommentaren",
    "An error occurred while trying to create the comment" : "Der opstod en fejl under forsøget på at oprette kommentaren"
},
"nplurals=2; plural=(n != 1);");
